#ifndef ActionFrame_h
#define ActionFrame_h

// $Id: ActionFrame.h,v 1.40 2014/02/25 09:53:42 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "Counter.h"
#include "File.h"
#include "LatexCommand.h"

#include <QCheckBox>
#include <QGroupBox>
#include <QPushButton>
#include <QRegExp>
#include <QList>
#include <QMap>

//! Set of buttons connected to latex related actions
class ActionFrame: public QGroupBox, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    ActionFrame( QWidget* parent );

    //! destructor
    virtual ~ActionFrame( void )
    { return; }

    //!@name modifiers
    //@{

    //! auto bibtex
    void setAutoBibtex( bool value );

    //! set file
    void setFile( const File& value )
    { file_ = value; }

    //! bibtex file available
    void updateBibtexFile( const File& );

    //@}

    Q_SIGNALS:

    //! request command
    void commandRequested( const LatexCommand& );

    //! request commands
    void commandsRequested( const LatexCommand::List& );

    //! commands aborted
    void commandsAborted( void );

    //! recent file added
    void recentFileAdded( const File& );

    //! cycles available
    void cyclesAvailable( int );

    public Q_SLOTS:

    //! busy
    void setBusy( void );

    //! iddle
    void setIdle( void );

    //! warnings
    void processWarning( const QString& );

    //! log
    void appendToLog( const QString& );

    protected Q_SLOTS:

    //! update button state
    void _updateButton( bool );

    //! process Button Pressed
    void _buttonPressed( void );

    //! abort
    void _abort( void );

    protected:

    //! state
    enum State
    {
        StateRunning,
        StateIdle
    };

    //! file
    const File& _file( void ) const
    { return file_; }

    //! returns true if button is checked
    bool _isChecked( LatexCommand::Type type )
    { return checkbox_[type]->isChecked(); }

    //! update action state
    void _updateActionState( void );

    private:

    //! current file
    File file_;

    //! bibliography file
    File bibtexFile_;

    //! checkboxes container
    QWidget* box_;

    //! checkboxes
    typedef QMap<LatexCommand::Type, QCheckBox*> CheckBoxMap;
    CheckBoxMap checkbox_;

    //! run/abort button
    QPushButton* button_;

    //! true if actions are beeing processed
    State state_;

    //! true if bibtex is to be used automatically
    bool autoBibtex_;

    //! warnings
    QStringList warnings_;
    QString warningLog_;

};

#endif
