#ifndef ButtonFrame_h
#define ButtonFrame_h

// $Id: ButtonFrame.h,v 1.23 2013/10/25 09:39:37 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "LatexCommand.h"

#include <QWidget>
#include <QPushButton>

//! Set of buttons connected to latex related actions
class ButtonFrame: public QWidget, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    ButtonFrame( QWidget* parent );

    //! destructor
    virtual ~ButtonFrame( void )
    {}

    //! edit button
    /*! it is needed because connected to MainWindow slot */
    QPushButton& editButton( void ) const
    { return *editButton_; }

    //! set file
    void setFile( const File& value )
    {
        file_ = value;
        updateButtons();
    }

    //! update buttons
    void updateButtons( void );

    Q_SIGNALS:

    //! recent file added
    void recentFileAdded( const File& );

    //! request latex command
    void commandRequested( const LatexCommand& );

    //! message
    void messageAvailable( const QString& );

    protected Q_SLOTS:

    //! clean
    void _clean( void )
    {
        emit commandRequested( LatexCommand( LatexCommand::Clean ) << file_ );
        updateButtons();
    }

    //! run dvi viewer
    void _viewDvi( void );

    //! run PS viewer
    void _viewPostscript( void );

    //! run PDF viewer
    void _viewPdf( void );

    private:

    //! file
    File file_;

    //! edit tex button
    QPushButton* editButton_;

    //! view dvi  button
    QPushButton* viewDviButton_;

    //! view ps button
    QPushButton* viewPostscriptButton_;

    //! view pdf button
    QPushButton* viewPdfButton_;

    //! clean
    QPushButton* cleanButton_;

};

#endif
