// $Id: ConfigurationDialog.cpp,v 1.35 2014/02/03 10:08:28 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConfigurationDialog.h"
#include "ConfigurationDialog.moc"

#include "Application.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "BaseIconNames.h"
#include "Debug.h"
#include "OptionBrowsedLineEditor.h"
#include "OptionCheckBox.h"
#include "RecentFilesConfiguration.h"
#include "Singleton.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>
#include <QPushButton>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent ):
BaseConfigurationDialog( parent )
{

    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setWindowTitle( "Configuration - Textool" );

    // base configuration
    baseConfiguration();

    {
        // text edition configuration
        OptionCheckBox* checkbox;
        QWidget* box = textEditConfiguration();
    }

    // commands
    QWidget *page( &addPage( IconEngine::get( IconNames::PreferencesFileAssociations ), tr( "Applications" ), tr( "Third-party applications" ) ) );
    {
        QWidget* box;
        page->layout()->addWidget( box = new QWidget( page ) );

        OptionBrowsedLineEditor* editor;
        GridLayout *gridLayout( new GridLayout() );
        box->setLayout( gridLayout );
        gridLayout->setMargin(0);
        gridLayout->setSpacing(5);
        gridLayout->setMaxCount(2);
        gridLayout->setColumnAlignment(0, Qt::AlignRight|Qt::AlignVCenter );

        gridLayout->addWidget( new QLabel( tr( "Latex:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "LATEX_COMMAND" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Bibtex:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "BIBTEX_COMMAND" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Dvi to ps:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_TO_PS" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Dvi to pdf:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_TO_PDF" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Postscript to pdf:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PS_TO_PDF" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Dvi viewer:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "DVI_VIEWER" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Postscript viewer:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PS_VIEWER" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Pdf viewer:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "PDF_VIEWER" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Text editor:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "TEXT_EDITOR" ) );
        addOptionWidget( editor );

        gridLayout->addWidget( new QLabel( tr( "Spell checker:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "SPELLCHECK" ) );
        addOptionWidget( editor );

    }

    // recent files
    page = &addPage( IconEngine::get( IconNames::PreferencesRecentFiles ), tr( "Recent Files" ), tr( "Recent files list settings" ), true );
    RecentFilesConfiguration* recentFilesConfiguration = new RecentFilesConfiguration( page, Singleton::get().application<Application>()->recentFiles() );
    page->layout()->addWidget( recentFilesConfiguration );
    addOptionWidget( recentFilesConfiguration );

    recentFilesConfiguration->read();
    connect( this, SIGNAL(ok()), recentFilesConfiguration, SLOT(write()) );
    connect( this, SIGNAL(apply()), recentFilesConfiguration, SLOT(write()) );
    connect( this, SIGNAL(reset()), recentFilesConfiguration, SLOT(reload()) );

    // misc
    page = &addPage( IconEngine::get( IconNames::PreferencesUnsorted ), tr( "Unsorted" ), tr( "Additional unsorted settings" ) );
    {
        QWidget* box = new QWidget( page );
        box->setLayout( new QVBoxLayout() );
        box->layout()->setMargin(5);
        box->layout()->setSpacing(5);
        page->layout()->addWidget( box );

        OptionCheckBox* checkbox;
        box->layout()->addWidget( checkbox = new OptionCheckBox( tr( "Auto-select bibtex when running latex command" ), box, "AUTO_BIBTEX" ) );
        addOptionWidget( checkbox );

        box->layout()->addWidget( checkbox = new OptionCheckBox( tr( "Make backup of files before editing includes" ), box, "SAVE_BACKUP" ) );
        addOptionWidget( checkbox );

    }

    // load initial configuration
    read();

}
