#ifndef IncludeFrame_h
#define IncludeFrame_h

// $Id: IncludeFrame.h,v 1.31 2014/02/25 10:26:57 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "File.h"
#include "IncludeFileModel.h"
#include "LatexCommand.h"
#include "TabWidget.h"
#include "TimeStamp.h"

#include <QAction>
#include <QPushButton>
#include <QFileSystemWatcher>

class TreeView;

//! parse input File and display includes recursively
class IncludeFrame:public TabWidget
{


    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    IncludeFrame( QTabWidget* parent = 0 );

    //! set file
    void setFile( const File& value )
    {
        file_ = value;
        requestUpdate();
    }

    //! include files
    IncludeFileModel::List files( void ) const
    { return model_.children(); }

    //! selected files
    IncludeFileModel::List selection( void ) const;

    //! check if files are modified
    bool filesModified( void );

    Q_SIGNALS:

    //! request latex command
    void commandRequested( const LatexCommand& );

    //! request latex command
    void commandsRequested( const LatexCommand::List& );

    //! message
    void messageAvailable( const QString& );

    public Q_SLOTS:

    //! request update
    void requestUpdate( void );

    //! update model from list of files
    void update( const IncludeFile::List& );

    protected Q_SLOTS:

    //! update actions enability
    void _updateActions( void );

    //! toggle (check/uncheck) item
    void _toggle( const QModelIndex&, bool = true );

    //! update buttons
    void _updateButtons( void );

    //! edit a File from list view
    void _edit( void );

    //! run spell checker on a File
    void _spellCheck( void );

    //! check all
    void _selectAll( void );

    //! uncheck all
    void _selectNone( void );

    //! invert selection
    void _invert( void );

    protected:

    //! returns true if file is on afs
    bool _fileIsAfs( const QString& ) const;

    private:

    //! actions
    void _installActions( void );

    //! file
    File file_;

    //! model
    IncludeFileModel model_;

    //! list
    TreeView* list_;

    //! file system watcher
    QFileSystemWatcher fileSystemWatcher_;

    //! last update
    TimeStamp lastUpdate_;

    //!@name actions
    //@{

    //! edit
    QAction* editAction_;

    //! run spellcheck
    QAction* spellcheckAction_;

    //! reload
    QAction* reloadAction_;

    //@}

    //!@name buttons
    //@{

    //! button widget
    QWidget* buttonWidget_;

    //! select all
    QPushButton* selectAllButton_;

    //! deselect
    QPushButton* selectNoneButton_;

    //! invert
    QPushButton* invertButton_;

    //! edit
    QPushButton* editButton_;

    //! spell check
    QPushButton* spellCheckButton_;

    //@}

};

#endif
