
// $Id: LatexCommand.cpp,v 1.4 2013/04/29 18:27:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LatexCommand.h"

//___________________________________________________________________
unsigned int& LatexCommand::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//___________________________________________________________________
LatexCommand::LatexCommand( const Type type ):
    Counter( "LatexCommand" ),
    id_( _counter()++ ),
    type_( type )
{}

//___________________________________________________________________
QString LatexCommand::name( const Type& type )
{
    Debug::Throw( "LatexCommand::name.\n" );

    if( _names().empty() ) _initializeNames();
    NameMap::const_iterator iter( _names().find( type ) );
    return iter != _names().end() ? iter.value():"";
}

//___________________________________________________________________
QString LatexCommand::path( void ) const
{
    switch( type_ )
    {
        case Latex:
        case PDFLatex:
        case Bibtex:
        case DviPS:
        case DviPDF:
        case PS2PDF:
        case CheckCitations:
        case CheckCitationOrder:
        case CheckLabels:
        case CheckReferences:
        case FindIncludes:
        case FindFigures:
        case Clean:
        return arguments_[0];

        default: return QString();
    }

}

//___________________________________________________________________
void LatexCommand::_initializeNames( void )
{
    Debug::Throw( "LatexCommand::_initializeNames.\n" );

    _names()[None] = QObject::tr( "none" );
    _names()[Latex] = QObject::tr( "run Latex" );
    _names()[PDFLatex] = QObject::tr( "run PdfLatex" );
    _names()[Bibtex] = QObject::tr( "run Bibtex" );
    _names()[DviPS] = QObject::tr( "convert Dvi to PS" );
    _names()[DviPDF] = QObject::tr( "convert Dvi to PDF" );
    _names()[PS2PDF] = QObject::tr( "convert PS to PDF" );
    _names()[CheckCitations] = QObject::tr( "check citations" );
    _names()[CheckCitationOrder] = QObject::tr( "check citations order" );
    _names()[CheckLabels] = QObject::tr( "check labels" );
    _names()[CheckReferences] = QObject::tr( "check references" );
    _names()[FindIncludes] = QObject::tr( "find included latex files" );
    _names()[FindFigures] = QObject::tr( "find figures" );
    _names()[ToggleIncludeFile] = QObject::tr( "toggle include file" );
    _names()[Clean] = QObject::tr( "remove temporary files" );

}

//___________________________________________________________________
LatexCommand::NameMap& LatexCommand::_names( void )
{
    static NameMap names;
    return names;
}
