#ifndef Menu_h
#define Menu_h

// $Id: Menu.h,v 1.21 2013/10/25 09:39:37 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "FileRecord.h"
#include "ValidFileThread.h"

#include <QMenuBar>
#include <QList>
#include <QPair>

class RecentFilesMenu;

/*!
\class   Menu
\brief   application main menu
*/

class Menu:public QMenuBar, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! creator
    Menu( QWidget* parent );

    //! destructor
    virtual ~Menu( void )
    { Debug::Throw( "Menu::~Menu.\n" ); }

    //! recent files menu
    RecentFilesMenu& recentFilesMenu( void ) const
    { return *recentFilesMenu_; }

    protected Q_SLOTS:

    //! process records from threads
    void _processRecords( const FileRecord::List&, bool );

    private Q_SLOTS:

    // update edition menu
    void _updateEditionMenu( void );

    private:

    // valid file thread
    ValidFileThread thread_;

    // recent file menu
    RecentFilesMenu* recentFilesMenu_;

    // edition
    QMenu* editionMenu_;

    //! map actions to file recors
    typedef QPair<QAction*, FileRecord> ActionPair;
    typedef QList<ActionPair> ActionMap;

    //! map actions to FileRecords
    ActionMap editionActions_;


};

#endif
