// $Id: TexString.cpp,v 1.17 2013/04/29 18:27:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TexString.h"
#include "File.h"

//________________________________________________________
const QString& TexString::header( void )
{
    static const QString header_(
        "\\NeedsTeXFormat{LaTeX2e}\n"
        "\\documentclass[10pt,a4paper]{article}\n"
        "\\usepackage[latin1]{inputenc}\n"
        "\\usepackage[T1]{fontenc}\n"
        "\n"
        "\\hoffset 0.cm\n"
        "\\voffset 1.cm\n"
        "\\oddsidemargin 0.cm\n"
        "\\evensidemargin 0.cm\n"
        "\\topmargin 0.cm\n"
        "\\headheight 0.mm\n"
        "\\headsep 0.mm\n"
        "\\textheight 23.cm\n"
        "\\textwidth 16.2cm\n"\
        "\\marginparsep 0.cm\n"
        "\\marginparwidth 0.cm\n"
        "\\footskip 1.cm\n"
        "\\parskip 3mm\n"
        "\\parindent 0mm\n"
        "\n"
        "\\begin{document}\n");
    return header_;
}

//________________________________________________________
const QString& TexString::trailer( void )
{
    static const QString trailer_( "\n\\end{document}\n" );
    return trailer_;
}

//________________________________________________________
QString TexString::addExtension( const QString& extension )
{

    // prepare output file
    QString out( *this );

    // remove file extension, if found:
    if( extensions().find(  File( *this ).extension() ) != extensions().end() )
    { out = File( *this ).truncatedName(); }

    // adds new extension
    out += extension;
    return out;
}

//________________________________________________________
QString TexString::toLatexAccents( void ) const
{
    QString out( *this );
    foreach( const Conversion& conversion, _conversions() )
    { if( !conversion.first.isEmpty() ) out = out.replace( conversion.first, conversion.second ); }
    return out;
}

//________________________________________________________
QString TexString::toTextAccents( void ) const
{
    QString out( *this );
    foreach( const Conversion& conversion, _conversions() )
    { if( !conversion.second.isEmpty() ) out = out.replace( conversion.second, conversion.first ); }
    return out;
}

//________________________________________________________
const TexString::ExtensionList& TexString::extensions( void )
{
    static ExtensionList extensions_;
    if( extensions_.empty() )
    {

        extensions_.insert( "tex" );
        extensions_.insert( "dvi" );
        extensions_.insert( "ps" );
        extensions_.insert( "pdf" );
        extensions_.insert( "aux" );
        extensions_.insert( "log" );
        extensions_.insert( "out" );
        extensions_.insert( "toc" );
        extensions_.insert( "tof" );
        extensions_.insert( "bib" );
        extensions_.insert( "bbl" );
        extensions_.insert( "blg" );
    }

    return extensions_;

}

//________________________________________________________
const TexString::ExtensionList& TexString::cleanExtensions( void )
{
    static ExtensionList cleanExtensions_;
    if( cleanExtensions_.empty() )
    {

        cleanExtensions_.insert( "dvi" );
        cleanExtensions_.insert( "aux" );
        cleanExtensions_.insert( "log" );
        cleanExtensions_.insert( "out" );
        cleanExtensions_.insert( "toc" );
        cleanExtensions_.insert( "tof" );
        cleanExtensions_.insert( "bbl" );
        cleanExtensions_.insert( "blg" );
    }

    return cleanExtensions_;

}

//________________________________________________________
const TexString::ConversionList& TexString::_conversions( void )
{
    static ConversionList conversions_;

    if( conversions_.empty() )
    {
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\`a" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\^a" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\\"a" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\'e" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\`e" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\^e" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\\"e" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\^\\i " );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\\"\\i " );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\^o" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\\"o" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\`u" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\^u" );
        conversions_ << Conversion( QString::fromLatin1( "" ), "\\c c" );
        // (wtf) conversions_ << Conversion( "?", "-" );
    }

    return conversions_;

}
